﻿using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;
using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace UGMultiCellPaste
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void ultraGrid1_BeforeMultiCellOperation(object sender, Infragistics.Win.UltraWinGrid.BeforeMultiCellOperationEventArgs e)
        {
            UltraGrid grid = (UltraGrid)sender;
            if (e.Operation == MultiCellOperation.Paste)
            {
                foreach (UltraGridCell cell in e.Cells)
                {
                    if (cell.Value.ToString() != "")
                    {
                        var result = MessageBox.Show("Some of the cells to paste within \n" +
                             "have existing data. Do you want to overwrite the existing values?", "Warning", MessageBoxButtons.OKCancel);

                        if (result == DialogResult.Cancel)
                        {
                            e.Cancel = true;
                            return;
                        }
                        else
                        {
                            break;
                        }
                    }
                }

                foreach (UltraGridCell cell in e.Cells)
                {
                    if (cell.Column.Key.ToString().Equals("Column 0") && (Int32.Parse(e.NewValues[cell].Value.ToString()) < 0 || (Int32.Parse(e.NewValues[cell].Value.ToString()) > 10)))
                    {
                        MessageBox.Show("All integers must be greater than 0 and less than 10");

                        e.Cancel = true;
                        break;
                    }
                    if (cell.Column.Key.ToString().Equals("DropDown Col")
                        && !((cell.Column.EditorComponent as UltraComboEditor).ValueList.FindByDataValue(e.NewValues[cell].Value) != null))
                    {
                        MessageBox.Show("Pasted values for \"DropDown Col\" should be of the possible items!");

                        e.Cancel = true;
                        break;

                    }
                    if (cell.Column.Key.ToString().Equals("DateColumn"))
                    {
                        CultureInfo enUS = new CultureInfo("en-US");
                        DateTime dDate;
                        bool isOfRequiredFormat = DateTime.TryParseExact(e.NewValues[cell].Value.ToString(), cell.Column.Format, enUS, DateTimeStyles.None, out dDate);
                        if (!isOfRequiredFormat)
                        {
                            MessageBox.Show("Pasted date values should match the exact date format!");
                            e.Cancel = true;
                            break;
                        }

                    }
                }
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            UltraComboEditor combo = new UltraComboEditor();
            List<string> vals = new List<string>() { "val 1", "val 2", "val 3" };

            foreach (string val in vals)
            {
                combo.ValueList.ValueListItems.Add(val);
            }
            combo.DropDownStyle = DropDownStyle.DropDownList;
            this.ultraGrid1.DisplayLayout.Bands[0].Columns["DropDown Col"].EditorComponent = combo;
        }
    }
}
